function [Utility] = Attributes(CAPEX_Daily,OPEX_Daily,Design_Space,...
    Total_Deck_Area,Contracts_Feasible,IMR_Availability,...
    SURF_Availability,LWI_Availability,DSV_Availability)
%This function calculates the utility of each design in each epoch based
%on the attributes for the tradespace exploration. 

%Initializing:
[num_epochs,num_designs] = size(Contracts_Feasible);
Utility = zeros(num_epochs,num_designs);
Utility_CAPEX = zeros(1,num_designs);
Utility_OPEX = zeros(1,num_designs);
Utility_Crane = zeros(1,num_designs);
Utility_IMR = zeros(num_epochs,num_designs);
Utility_SURF = zeros(num_epochs,num_designs);
Utility_LWI = zeros(num_epochs,num_designs);
Utility_DSV = zeros(num_epochs,num_designs);
Utility_Deck_Area = zeros(1,num_designs);

%Identifying the minimum and maximum values for each attribute:
%CAPEX attribute:
Utility_Min(1) = max(CAPEX_Daily(:,1));
Utility_Max(1) = min(CAPEX_Daily(:,1));
%OPEX attribute:
Utility_Min(2) = max(OPEX_Daily(:,1));
Utility_Max(2) = min(OPEX_Daily(:,1));
%Crane attribute: 
Utility_Min(3) = min(Design_Space(:,1));
Utility_Max(3) = max(Design_Space(:,1));
%Total deck area attribute:
Utility_Min(4) = min(Total_Deck_Area);
Utility_Max(4) = max(Total_Deck_Area);
%Contract availability attribute:
for e = 1:num_epochs
%IMR availability: 
IMR_Utility_Min(e) = min(IMR_Availability(e,:));
IMR_Utility_Max(e) = max(IMR_Availability(e,:));
%SURF availability: 
SURF_Utility_Min(e) = min(SURF_Availability(e,:));
SURF_Utility_Max(e) = max(SURF_Availability(e,:));
%LWI availability: 
LWI_Utility_Min(e) = min(LWI_Availability(e,:));
LWI_Utility_Max(e) = max(LWI_Availability(e,:));
%DSV availability: 
DSV_Utility_Min(e) = min(DSV_Availability(e,:));
DSV_Utility_Max(e) = max(DSV_Availability(e,:));
%Nr. of Contracts feasible attribute: 
Con_Utility_Min(e) = min(Contracts_Feasible(e,:));
Con_Utility_Max(e) = max(Contracts_Feasible(e,:));
end

%Defining the utility function of each performance attribute: 
for d = 1:num_designs
    Utility_CAPEX(d) = ...
    (CAPEX_Daily(d,1)-Utility_Min(1))/(Utility_Max(1)-Utility_Min(1));
    Utility_OPEX(d) = ...
        (OPEX_Daily(d,1)-Utility_Min(2))/...
        (Utility_Max(2)-Utility_Min(2));
    Utility_Crane(d) = ...
        (Design_Space(d,1)-Utility_Min(3))/...
        (Utility_Max(3)-Utility_Min(3));
    Utility_Deck_Area(d) = ...
        (Total_Deck_Area(d)-Utility_Min(4))/...
        (Utility_Max(4)-Utility_Min(4));   
    for e = 1:num_epochs
        %IMR availability attribute:
        if (IMR_Utility_Max(e) > 0)
            if (IMR_Utility_Min(e) < IMR_Utility_Max(e))
                Utility_IMR(e,d) = ...
                    (IMR_Availability(e,d)-IMR_Utility_Min(e))/...
                    (IMR_Utility_Max(e)-IMR_Utility_Min(e));
            elseif (IMR_Utility_Max(e) - IMR_Utility_Min(e) == 0)
                Utility_IMR(e,d) = 1;
            end
        else
            Utility_IMR(e,d) = 0;
        end
        %SURF availability attribute: 
        if (SURF_Utility_Max(e) > 0)
            if (SURF_Utility_Min(e) < SURF_Utility_Max(e))
                Utility_SURF(e,d) = ...
                    (SURF_Availability(e,d)-SURF_Utility_Min(e))/...
                    (SURF_Utility_Max(e)-SURF_Utility_Min(e));
            elseif SURF_Utility_Max(e) - SURF_Utility_Min(e) == 0
                Utility_SURF(e,d) = 1;
            end
        else
            Utility_SURF(e,d) = 0;
        end
        %LWI availability attribute:
        if (LWI_Utility_Max(e) > 0)
            if (LWI_Utility_Min(e) < LWI_Utility_Max(e))
                Utility_LWI(e,d) = ...
                    (LWI_Availability(e,d)-LWI_Utility_Min(e))/...
                    (LWI_Utility_Max(e)-LWI_Utility_Min(e));
            elseif LWI_Utility_Max(e) - LWI_Utility_Min(e) == 0
                Utility_LWI(e,d) = 1;
            end
        else
            Utility_LWI(e,d) = 0;
        end
        %DSV availability attribute:
        if (DSV_Utility_Max(e) > 0)
            if (DSV_Utility_Min(e) < DSV_Utility_Max(e))
                Utility_DSV(e,d) = ...
                    (DSV_Availability(e,d)-DSV_Utility_Min(e))/...
                    (DSV_Utility_Max(e)-DSV_Utility_Min(e));
            elseif DSV_Utility_Max(e) - DSV_Utility_Min(e) == 0
                Utility_DSV(e,d) = 1;
            end
        else
            Utility_DSV(e,d) = 0;
        end
    end
end
%The total utility of a design in an epoch is calculated by weighting the
%performance attributes equally. 
for e = 1:num_epochs
    for d = 1:num_designs
        Utility(e,d) = (1/8)*(Utility_CAPEX(d) + Utility_OPEX(d) ...
            + Utility_Crane(d) + Utility_IMR(e,d) + Utility_SURF(e,d) ...
            + Utility_LWI(e,d) + Utility_DSV(e,d) + Utility_Deck_Area(d));
        if (Utility_IMR(e,d) == 0) && (Utility_SURF(e,d) == 0) && ...
            (Utility_LWI(e,d) == 0) && (Utility_DSV(e,d) == 0)
            Utility(e,d) = 0;
        end
    end
end
end