function [All_Contracts_Availability,IMR_Availability,SURF_Availability,...
    LWI_Availability,DSV_Availability] = AvailableContracts...
    (Epoch_Space,IMR_Contract,SURF_Contract,LWI_Contract,DSV_Contract)
%This function generates a number of available contracts based on epoch
%variables and vessel feasibility. 

%Initializing:
markets = 4;
[num_epochs,num_designs] = size(IMR_Contract);
IMR_Availability_ = zeros(num_epochs,1);
SURF_Availability_ = zeros(num_epochs,1);
LWI_Availability_ = zeros(num_epochs,1);
DSV_Availability_ = zeros(num_epochs,1);
IMR_Availability = zeros(num_epochs,num_designs);
SURF_Availability = zeros(num_epochs,num_designs);
LWI_Availability = zeros(num_epochs,num_designs);
DSV_Availability = zeros(num_epochs,num_designs);
All_Contracts_Availability = zeros(num_epochs,num_designs,markets);

for i = 1:num_epochs
    %Defining contracts available based on epoch variables: 
    %IMR availability only depends on oil price:
    IMR_Availability_(i) = 4 + ...
        6*((Epoch_Space(i,1) - min(Epoch_Space(:,1)))/...
        (max(Epoch_Space(:,1)) - min(Epoch_Space(:,1))));
    %SURF availability depends on oil price and tie-in: 
    SURF_Availability_(i) = 2 + ...
        6*((Epoch_Space(i,1) - min(Epoch_Space(:,1)))/...
        (max(Epoch_Space(:,1)) - min(Epoch_Space(:,1))))...
        + 2*((Epoch_Space(i,4) - min(Epoch_Space(:,4)))/...
        (max(Epoch_Space(:,4)) - min(Epoch_Space(:,4))));
    %LWI availability depends on oil price and water depth: 
    LWI_Availability_(i) = 2 + ...
        6*((Epoch_Space(i,1) - min(Epoch_Space(:,1)))/...
        (max(Epoch_Space(:,1)) - min(Epoch_Space(:,1))))...
        + 2*((Epoch_Space(i,3) - min(Epoch_Space(:,3)))/...
        (max(Epoch_Space(:,3)) - min(Epoch_Space(:,3))));
    %DSV availability depends on oil price, water depth and tie-in need: 
    DSV_Availability_(i) = 4 + ...
        6*((Epoch_Space(i,1) - min(Epoch_Space(:,1)))/...
        (max(Epoch_Space(:,1)) - min(Epoch_Space(:,1))))...
        - 2*((Epoch_Space(i,3) - min(Epoch_Space(:,3)))/...
        (max(Epoch_Space(:,3)) - min(Epoch_Space(:,3))))...
        + 2*((Epoch_Space(i,4) - min(Epoch_Space(:,4)))/...
        (max(Epoch_Space(:,4)) - min(Epoch_Space(:,4))));
    %Defining only the feasible designs as having contracts available: 
    for j = 1:num_designs
        IMR_Availability(i,j) = IMR_Contract(i,j)*IMR_Availability_(i);
        SURF_Availability(i,j) = SURF_Contract(i,j)*SURF_Availability_(i);
        LWI_Availability(i,j) = LWI_Contract(i,j)*LWI_Availability_(i);
        DSV_Availability(i,j) = DSV_Contract(i,j)*DSV_Availability_(i);
    end
end
%Generating a matrix with the number of contracts available for all
%markets in each epoch.
All_Contracts_Availability(:,1) = IMR_Availability_(:);
All_Contracts_Availability(:,2) = SURF_Availability_(:);
All_Contracts_Availability(:,3) = LWI_Availability_(:);
All_Contracts_Availability(:,4) = DSV_Availability_(:);

end