function [All_Contracts,Contracts_Feasible,IMR_Contract,SURF_Contract,...
    LWI_Contract,DSV_Contract] = Contracts(Min_Req_Space,Design_Space)
%This function checks contract feasibility for designs in each epoch. 

%Initializing:
[num_designs,dvs] = size(Design_Space);
[num_epochs,markets,dvs] = size(Min_Req_Space);
IMR_requirement = zeros(num_epochs,num_designs,dvs);
SURF_requirement = zeros(num_epochs,num_designs,dvs);
LWI_requirement = zeros(num_epochs,num_designs,dvs);
DSV_requirement = zeros(num_epochs,num_designs,dvs);
IMR_Contract = zeros(num_epochs,num_designs);
SURF_Contract = zeros(num_epochs,num_designs);
LWI_Contract = zeros(num_epochs,num_designs);
DSV_Contract = zeros(num_epochs,num_designs);
Contracts_Feasible = zeros(num_epochs,num_designs);
All_Contracts = zeros(num_epochs,num_designs,markets);
%Defines whether or not a design matches the minimum requirements in a
%contract: 
for i = 1:num_epochs
    for j = 1:num_designs
        for d = 1:dvs
            %Checking whether the individual requirements on design
            %variable values are fulfilled:
            if Design_Space(j,d) >= Min_Req_Space(i,1,d)
                IMR_requirement(i,j,d) = 1;
            end
            if Design_Space(j,d) >= Min_Req_Space(i,2,d)
                SURF_requirement(i,j,d) = 1;
            end
            if Design_Space(j,d) >= Min_Req_Space(i,3,d)
                LWI_requirement(i,j,d) = 1;
            end
            if Design_Space(j,d) >= Min_Req_Space(i,4,d)
                DSV_requirement(i,j,d) = 1;
            end
        end
        %Checking if all requirements are fulfilled:
        if sum(IMR_requirement(i,j,:)) == dvs
            IMR_Contract(i,j) = 1;
        end
        if sum(SURF_requirement(i,j,:)) == dvs
            SURF_Contract(i,j) = 1;
        end
        if sum(LWI_requirement(i,j,:)) == dvs
            LWI_Contract(i,j) = 1;
        end
        if sum(DSV_requirement(i,j,:)) == dvs
            DSV_Contract(i,j) = 1;
        end
        %Finds the total number of feasible contracts for each design in
        %each epoch: 
        Contracts_Feasible(i,j) = IMR_Contract(i,j) ...
            + SURF_Contract(i,j) + LWI_Contract(i,j) + DSV_Contract(i,j);
    end
end
%Creating a matrix defining feasibility of designs in all epochs for all
%markets, in one single matrix: 
All_Contracts(:,:,1) = IMR_Contract(:,:);
All_Contracts(:,:,2) = SURF_Contract(:,:);
All_Contracts(:,:,3) = LWI_Contract(:,:);
All_Contracts(:,:,4) = DSV_Contract(:,:);
end