function [CAPEX_Total,CAPEX_Daily,OPEX_Daily] = ...
    Costs(Design_Variables,Design_Space,Total_Deck_Area,...
    T_life,T_payback,CAPEX_DV,r_discount)
%This function calculates CAPEX and OPEX. 

%Initializing:
[num_designs,dvs] = size(Design_Space);
[levels,dvs] = size(Design_Variables);
CAPEX_Total = zeros(1,num_designs);
loan_remaining = zeros(1,num_designs);
CAPEX_equity = zeros(1,num_designs);
CAPEX_loan = zeros(1,num_designs);
CAPEX1 = zeros(num_designs,T_life);
CAPEX_Daily = zeros(num_designs,T_life);
OPEX_Daily = zeros(num_designs,1);

%Calculating the CAPEX for all design alternatives: 
for d = 1:num_designs
    %Calculating the "platform design" building cost in MNOK, 
    %as a function of total deck area:
    CAPEX_Total(d) = 440 + 40*((Total_Deck_Area(d) - 1000)/250);
    %Including the CAPEX for installing the design variables in the design:
    for j = 1:dvs
        for l = 1:levels
            if Design_Space(d,j) == Design_Variables(l,j)
                CAPEX_Total(d) = CAPEX_Total(d) + 1.2*CAPEX_DV(l,j);
            end
        end
    end
    %CAPEX split in equity and loan: 
    CAPEX_equity(d) = 0.3*CAPEX_Total(d);
	CAPEX_loan(d) = 0.7*CAPEX_Total(d);
    loan_remaining(d) = CAPEX_loan(d);
    for t = 1:T_life
        %Calculating CAPEX paid per period as long as loan remains. 
        if t <= T_payback
            CAPEX1(d,t) = ...
            CAPEX_equity(d)/T_life + CAPEX_loan(d)/T_payback...
            + r_discount*loan_remaining(d);
            loan_remaining(d) = loan_remaining(d)...
            - (1/T_payback)*loan_remaining(d);
        %Calculating CAPEX paid per period when loan is repaid. 
        else
            CAPEX1(d,t) = CAPEX_equity(d)/T_life;
        end
        %CAPEX paid per day, each year. 
        CAPEX_Daily(d,t) = CAPEX1(d,t)/365;
    end
    %Operational expenditures found as a function of CAPEX:
    OPEX_Daily(d,:) = 46000/(10^6) + (CAPEX_Total(d)*(6.8/100))/365;
end
end