function [Design_Space,Design_Space_infeasible,Total_Deck_Area] = ...
    Designs(Design_Variables,levels_desvar,Deck_Area,...
    Accommodation_Required,Min_Req)
%This function creates all the designs that are feasible, based on the
%design variables defined and constraints on the design space. 

%Initializing design variables:
DesVar_Crane = zeros(1,levels_desvar(1));
DesVar_Free_Deck_Area = zeros(1,levels_desvar(2));
DesVar_Accommodation = zeros(1,levels_desvar(3));
DesVar_LARS_ROV = zeros(1,levels_desvar(11));
DesVar_Mod_Hand = zeros(1,levels_desvar(4));
DesVar_Well_Int = zeros(1,levels_desvar(5));
DesVar_J_Lay = zeros(1,levels_desvar(6));
DesVar_Carousel = zeros(1,levels_desvar(7));
DesVar_Sat_Div = zeros(1,levels_desvar(8));
DesVar_Chemicals = zeros(1,levels_desvar(9));
DesVar_Skidding = zeros(1,levels_desvar(10));

%Defining all design variables: 
for i = 1:max(levels_desvar)
    if i <= levels_desvar(1)
        DesVar_Crane(i) = Design_Variables(i,1);
    end
    if i <= levels_desvar(2)
        DesVar_Free_Deck_Area(i) = Design_Variables(i,2);
    end
    if i <= levels_desvar(3)
        DesVar_Accommodation(i) = Design_Variables(i,3);
    end
    if i <= levels_desvar(4)
        DesVar_Mod_Hand(i) = Design_Variables(i,4);
    end
    if i <= levels_desvar(5)
        DesVar_Well_Int(i) = Design_Variables(i,5);
    end
    if i <= levels_desvar(6)
        DesVar_J_Lay(i) = Design_Variables(i,6);
    end
    if i <= levels_desvar(7)
        DesVar_Carousel(i) = Design_Variables(i,7);
    end
    if i <= levels_desvar(8)
        DesVar_Sat_Div(i) = Design_Variables(i,8);
    end
    if i <= levels_desvar(9)
        DesVar_Chemicals(i) = Design_Variables(i,9);
    end
    if i <= levels_desvar(10)
        DesVar_Skidding(i) = Design_Variables(i,10);
    end
    if i <= levels_desvar(11)
        DesVar_LARS_ROV(i) = Design_Variables(i,11);
    end
end
 
%Generating all potentially possible designs (feasible and infeasible): 
DesVars = {DesVar_Crane, DesVar_Free_Deck_Area, DesVar_Accommodation, ...
           DesVar_Mod_Hand, DesVar_Well_Int, DesVar_J_Lay, ...
           DesVar_Carousel, DesVar_Sat_Div, DesVar_Chemicals, ...
           DesVar_Skidding, DesVar_LARS_ROV};
[a b c d e f g h i j k] = ndgrid(DesVars{:});
Design_Space_infeasible = ...
    [a(:) b(:) c(:) d(:) e(:) f(:) g(:) h(:) i(:) j(:) k(:)];
[num_designs_1,dvs] = size(Design_Space_infeasible);

%Initializing: 
Total_Deck_Area_1 = zeros(num_designs_1,dvs);
%Defining the deck area needed for systems installed
for i = 1:num_designs_1
    %Setting total deck area initially equal to free deck area: 
    Total_Deck_Area_1(i) = Design_Space_infeasible(i,2);
    %Adding required deck area for systems to the total deck area: 
    for j = 1:dvs
        if Design_Space_infeasible(i,j) > 0
            Total_Deck_Area_1(i) = Total_Deck_Area_1(i) + Deck_Area(j);
        end
    end
    %Rounding to closest 250 m^2: 
    if Total_Deck_Area_1(i) <= 1000
        Total_Deck_Area_1(i) = 1000;
    elseif (Total_Deck_Area_1(i) > 1000) && (Total_Deck_Area_1(i) <= 1250)
        Total_Deck_Area_1(i) = 1250;
    elseif (Total_Deck_Area_1(i) > 1250) && (Total_Deck_Area_1(i) <= 1500)
        Total_Deck_Area_1(i) = 1500;
    elseif (Total_Deck_Area_1(i) > 1500) && (Total_Deck_Area_1(i) <= 1750)
        Total_Deck_Area_1(i) = 1750;
    elseif (Total_Deck_Area_1(i) > 1750) && (Total_Deck_Area_1(i) <= 2000)
        Total_Deck_Area_1(i) = 2000;
    end
end

%Initializing:
Accommodation_Total = zeros(1,num_designs_1);
%Defining the accommodation needed for systems installed: 
for i = 1:num_designs_1
    %Setting initial accommodation to 50: 
    Accommodation_Total(i) = 50;
    %Adding accommodation needed for systems: 
    for j = 1:dvs
        if Design_Space_infeasible(i,j) > 0
            Accommodation_Total(i) = ...
                Accommodation_Total(i) + Accommodation_Required(j);
        end
    end
end

%Initializing the designs that are to be allowed for analysis: 
Design = ones(num_designs_1,1);
%Pruning the design space, excluding infeasible designs:
for i = 1:num_designs_1
    %Module handling tower, well intervention tower, j-lay rig and
    %saturated diving system can not co-exist in the same design. 
    if ((Design_Space_infeasible(i,4) + Design_Space_infeasible(i,5)...
        + Design_Space_infeasible(i,6) + Design_Space_infeasible(i,8)) > 1)
        Design(i) = 0;
    %Module handling tower requires skidding system, and vice versa, 
    %so if the sum of these are 1, the design is infeasible. 
    elseif ((Design_Space_infeasible(i,4) ...
            + Design_Space_infeasible(i,10)) == 1)
        Design(i) = 0;
    %Module handling tower requires two LARS for WROV:
    elseif ((Design_Space_infeasible(i,4) ...
            - Design_Space_infeasible(i,11)) > -1)
        Design(i) = 0;
    %J-lay rigs require carousels, and vice versa, so if the sum of
    %these are 1, the design is infeasible.
    elseif ((Design_Space_infeasible(i,6) ...
            + Design_Space_infeasible(i,7)) == 1)
       Design(i) = 0;
    %Well intervention tower requires chemicals:
    elseif ((Design_Space_infeasible(i,5) ...
            - Design_Space_infeasible(i,9)) > 0)
        Design(i) = 0;            
    %Well intervention tower requires two LARS for WROV:
    elseif ((Design_Space_infeasible(i,5) ...
            - Design_Space_infeasible(i,11)) > -1)
        Design(i) = 0;   
    %Saturated diving system requires two LARS for WROV: 
    elseif ((Design_Space_infeasible(i,8) ...
            - Design_Space_infeasible(i,11)) > -1)
        Design(i) = 0;
    %At least the required amount of accommodation should be included in
    %the vessel: 
    elseif (Design_Space_infeasible(i,3) < Accommodation_Total(i))
        Design(i) = 0;
    %Total deck area is maximum 2000 m^2.
    elseif Total_Deck_Area_1(i) > 2000
        Design(i) = 0;
    end
end       
%Pruning the design space, excluding designs not feasible for initial IMR
%contract:
for i = 1:num_designs_1
    for d = 1:dvs
        if (Design_Space_infeasible(i,d) < Min_Req(1,d))
            Req(i,d) = 0;
        else
            Req(i,d) = 1;
        end
    end
    if sum(Req(i,:)) ~= dvs
        Design(i) = 0;
    end
end

%Initializing output variables: 
Design_Space = [];
Total_Deck_Area = [];
%Defining design space and total deck area: 
for i = 1:num_designs_1
    if Design(i) == 1;
        Design_Space = [Design_Space_infeasible(i,:); Design_Space];
        Total_Deck_Area = [Total_Deck_Area_1(i); Total_Deck_Area];
    end
end