function [NPV_Vessel_Flexible,Contract_Flex,Design_Transition,...
    Mean_NPV_Flexible] = FlexibleVesselNPV(Design_Selected,...
    All_Contracts,Era_Epoch_Progression,era,Transition,Transition_Cost,...
    T_con,Time_Charter_Contract,CAPEX_Daily,OPEX_Daily,r_discount)
%This function calculates the expected NPV for a vessel for which
%flexibility can be exercised according to some transition rules. 

%Initializing:
[n,markets,T_life] = size(Time_Charter_Contract);
[num_epochs,num_designs,markets] = size(All_Contracts);
[num_periods,num_eras] = size(Era_Epoch_Progression);
NPV_Vessel_Flexible = zeros(1,n);
Contract_Flex = zeros(num_periods,n);
Design_Transition = Design_Selected*ones(num_periods,n);
NPV_Epoch_Flex = zeros(n,markets,num_designs,num_periods);

%Monte Carlo loop:
for i = 1:n
    %First contract certain IMR contract:
    for t = 1:T_con
        NPV_Vessel_Flexible(i) = (350*Time_Charter_Contract(i,1,t) ...
            - 365*(CAPEX_Daily(Design_Selected,t) ...
            + OPEX_Daily(Design_Selected)))/(r_discount) ...
            + NPV_Vessel_Flexible(i);
    end
    Contract_Flex(1,i) = 1;
    d = Design_Selected;
    %Later contracts:
    for t = (T_con+1):T_life
        %Matches year and contract period.
        if (t >= T_con+1) && (t < 2*T_con+1)
            tt = 2;
        elseif (t >= 2*T_con+1) && (t < 3*T_con+1)
            tt = 3;
        elseif (t > 3*T_con+1) && (t < 4*T_con+1)
            tt = 4;
        elseif (t > 4*T_con+1) && (t < 5*T_con+1)
            tt = 5;
        end
        %Current design is the one transitioned into. 
        d = Design_Transition(tt-1,i);
        for j = 1:num_designs
            for m = 1:markets
                %Can never make a transition that would not be allowed from
                %the initial design. 
                if Transition(Design_Selected,j) == 0
                    NPV_Epoch_Flex(i,m,j,tt) = -inf;
                elseif Transition(Design_Selected,j) == 1
                    %The case that design d is infeasible for a market m. 
                    %Check the opportunity for transitioning: 
                    if (All_Contracts(Era_Epoch_Progression(tt,era(i)),...
                            d,m) == 0)
                        %If contract m is unavailable for design j: 
                        if (All_Contracts(Era_Epoch_Progression...
                                (tt,era(i)),j,m) == 0)
                            NPV_Epoch_Flex(i,m,j,tt) = -inf;
                        %If contract m is available for design j: 
                        elseif (All_Contracts(Era_Epoch_Progression...
                                (tt,era(i)),j,m) == 1)
                            %Accounting for the time taken to exercise
                            %options: 
                            Nr_Days_Operative = 330;
                            %Calculating NPV for epoch: 
                            NPV_Epoch_Flex(i,m,j,tt) ...
                                = (Nr_Days_Operative*...
                                Time_Charter_Contract(i,m,t) ...
                                - 365*(CAPEX_Daily(Design_Selected,t) ...
                                + OPEX_Daily(j)) ...
                                - Transition_Cost(d,j,tt))...
                                /(1+r_discount) + NPV_Epoch_Flex(i,m,j,tt);
                        end
                    %The case that design d is feasible for a market m. 
                    elseif (All_Contracts(Era_Epoch_Progression...
                            (tt,era(i)),d,m) == 1)
                        %If contract m is unavailable for design j: 
                        if (All_Contracts(Era_Epoch_Progression...
                                (tt,era(i)),j,m) == 0)
                            NPV_Epoch_Flex(i,m,j,tt) = -inf;
                        %If contract m is available for design j: 
                        elseif (All_Contracts(Era_Epoch_Progression...
                                (tt,era(i)),j,m) == 1)
                            %Days operative dependent on whether changes
                            %are made: 
                            if j == d;
                                Nr_Days_Operative = 350;
                            else
                                Nr_Days_Operative = 330;
                            end
                            %Calculating NPV for epoch:
                            NPV_Epoch_Flex(i,m,j,tt) ...
                                = (Nr_Days_Operative*...
                                Time_Charter_Contract(i,m,t) ...
                                - 365*(CAPEX_Daily(Design_Selected,t) ...
                                + OPEX_Daily(j)) ...
                                - Transition_Cost(d,j,tt))...
                                /(1+r_discount) + ...
                                NPV_Epoch_Flex(i,m,j,tt);
                        end
                    end
                end
            end
            %Maximizing NPV with regards to market. 
            Current_NPV_Epoch(i,j,tt) = max(NPV_Epoch_Flex(i,:,j,tt));
        end
        %Finding the design (transition) giving this NPV. 
        [NPV(tt,i),Design_Transition(tt,i)] = ...
            max(Current_NPV_Epoch(i,:,tt));
        %Identifying the contract that gives this NPV.
        for m = 1:markets
            if NPV(tt,i) == NPV_Epoch_Flex(i,m,Design_Transition(tt,i),tt)
                Contract_Flex(tt,i) = m;
            end
            for j = 1:num_designs
                NPV_Epoch_Flex(i,m,j,tt) = 0;
            end
        end
        NPV_Vessel_Flexible(i) = NPV(tt,i) + NPV_Vessel_Flexible(i);
    end
end                 
%Calculating the mean NPV for the flexible design: 
Mean_NPV_Flexible = mean2(NPV_Vessel_Flexible(:));
end
