function [NPV_Vessel_Inflexible,Contract_Inflex,Mean_NPV_Inflexible] ...
    = InflexibleVesselNPV(Era_Epoch_Progression,All_Contracts,era,...
    Design_Selected,T_con,Time_Charter_Contract,CAPEX_Daily,OPEX_Daily,...
    r_discount)
%This function calculates the net present value of one selected vessel 
%over its lifetime, given that it is not allowed to change. 

%Initializing:
[n,markets,T_life] = size(Time_Charter_Contract);
[num_epochs,num_designs,markets] = size(All_Contracts);
[num_periods,num_eras] = size(Era_Epoch_Progression);
NPV_Vessel_Inflexible = zeros(1,n);
NPV_Epoch_Inflex = zeros(n,markets,num_designs,num_periods);
Contract_Inflex = zeros(num_periods,n);
%Current design selection: 
d = Design_Selected;

%Monte Carlo loop: 
for i = 1:n
    %First contract is a certain IMR contract!
    for t = 1:T_con
        NPV_Vessel_Inflexible(i) = (350*Time_Charter_Contract(i,1,t) ...
            - 365*(CAPEX_Daily(Design_Selected,t) ...
            + OPEX_Daily(Design_Selected)))/(r_discount) ...
            + NPV_Vessel_Inflexible(i);
    end
    Contract_Inflex(1,i) = 1;
    %Evaluating NPV for vessel d assuming that the vessel can not be
    %changed. 
    for t = (T_con+1):T_life
        %Matches year and contract period.
        if (t >= T_con+1) && (t < 2*T_con+1)
            tt = 2;
        elseif (t >= 2*T_con+1) && (t < 3*T_con+1)
            tt = 3;
        elseif (t > 3*T_con+1) && (t < 4*T_con+1)
            tt = 4;
        elseif (t > 4*T_con+1) && (t < 5*T_con+1)
            tt = 5;
        end
        %Calculating the NPV for each epoch for design d in each market. 
        for m = 1:markets
            %NPV if contract is feasible. 
            if (All_Contracts(Era_Epoch_Progression(tt,era(i)),d,m) == 1)
                NPV_Epoch_Inflex(i,m,d,tt) = ...
                    (350*Time_Charter_Contract(i,m,t) ...
                    - 365*(CAPEX_Daily(d,t) + OPEX_Daily(d)))/...
                    (1+r_discount) + NPV_Epoch_Inflex(i,m,d,tt);
            %NPV if contract is infeasible. 
            else
                NPV_Epoch_Inflex(i,m,d,tt) = ...
                    - 365*(CAPEX_Daily(d,t) + OPEX_Daily(d))/...
                    (1+r_discount) + NPV_Epoch_Inflex(i,m,d,tt);
            end
        end
    end
    %Selecting most profitable contract for current epoch:
    for tt = 2:num_periods
        [Current_NPV_Epoch(i,tt),Contract_Inflex(tt,i)] ...
            = max(NPV_Epoch_Inflex(i,:,d,tt));
        if (All_Contracts(Era_Epoch_Progression(tt,era(i)),d,...
                Contract_Inflex(tt,i)) == 0)
            Contract_Inflex(tt,i) = 0;
        end
        NPV_Vessel_Inflexible(i) = ...
            NPV_Vessel_Inflexible(i) + Current_NPV_Epoch(i,tt);
    end
end

%Computing mean NPV for inflexible design:
Mean_NPV_Inflexible = mean2(NPV_Vessel_Inflexible);
end