%This script contains the input data for the analysis:

clear all;
clc;

%% DESIGN DESCRIPTION:
%Design variables: 
    % 1. Crane          Range: 100 - 300,   Step: 50,   Levels: 5
    % 2. Free deck area Range: 0 - 1500,    Step: 250,  Levels: 6
    % 3. Accommodation  Range: 50 - 150,    Step: 100,  Levels: 2
    % 4. Module hand.   Range: 0 - 1,       Step: 1,    Levels: 2
    % 5. Well interv.   Range: 0 - 1,       Step: 1,    Levels: 2
    % 6. J-lay tower    Range: 0 - 1,       Step: 1,    Levels: 2
    % 7. Carousel       Range: 0 - 1,       Step: 1,    Levels: 2
    % 8. Sat. diving.   Range: 0 - 1,       Step: 1,    Levels: 2
    % 9. Chemicals      Range: 0 - 1,       Step: 1,    Levels: 2
    % 10.Skidding sys.  Range: 0 - 1,       Step: 1,    Levels: 2
    % 11.LARS for WROV  Range: 1 - 2,       Step: 1,    Levels: 2
Design_Variables = [100,  0,  50, 0, 0, 0, 0, 0, 0, 0, 1;
                    150, 250, 150,1, 1, 1, 1, 1, 1, 1, 2;
                    200, 500, 0,  0, 0, 0, 0, 0, 0, 0, 0;
                    250, 1000,0,  0, 0, 0, 0, 0, 0, 0, 0;
                    300, 1250,0,  0, 0, 0, 0, 0, 0, 0, 0;
                    0,   1500,0,  0, 0, 0, 0, 0, 0, 0, 0];

%Total number of alternative levels for each design variable:
levels_desvar = [5,6,2,2,2,2,2,2,2,2,2];
%Deck area (m^2) required for each of the design variables (except free 
%deck area, decided within "Designs.m"): 
Deck_Area = [20,0,0,100,150,200,300,250,0,500,25];
%Accommodation required for each design variable: 
Accommodation_Required = [4,0,0,8,16,16,0,24,4,0,6];
%Initial contractual requirements to design variables: 
Min_Req =       [100, 500, 50, 0, 0, 0, 0, 0, 1, 0, 1;            %IMR
                 200, 1000,150,0, 0, 0, 0, 0, 0, 0, 1;            %SURF
                 100, 500, 150,0, 1, 0, 0, 0, 1, 0, 2;            %LWI
                 0  , 0,   150,0, 0, 0, 0, 1, 0, 0, 2];           %DSV
%Capital expenditures associated with design variables (MNOK): 
CAPEX_DV =      [28.75,0,10, 0,  0,  0,  0,  0,  0, 0, 9;
                 32.5, 0,30,25,115,220,0.8,160,4.3, 1,18;
                 37.5, 0, 0, 0,  0,  0,  0,  0,  0, 0, 0;
                 40,   0, 0, 0,  0,  0,  0,  0,  0, 0, 0;
                 42.5, 0, 0, 0,  0,  0,  0,  0,  0, 0, 0
                 0,    0, 0, 0,  0,  0,  0,  0,  0, 0, 0];  

%% ECONOMICS DESCRIPTION: 
%Economic information: 
T_life = 25;
T_payback = 12;
%Risk adjusted discount rate:
r_discount = 0.2;
%Length of one contract:
T_con = 5;

%% UNCERTAINTY DESCRIPTION: 
%Epoch variables: 
    % 1. Oil price      Range: 10 - 100,    Step: 30,   Levels: 4
    % 2. Module size    Range: 200 - 300,   Step: 50,   Levels: 3
    % 3. Water depth    Range: 1000 - 3000, Step: 1000, Levels: 3
    % 4. Tie in         Range: 0 - 1,       Step: 1,    Levels: 2
    % 5. Fibrerope      Range: 0 - 1,       Step: 1,    Levels: 2
Epoch_Variables = [10, 200, 1000, 0, 0;
                   40, 250, 2000, 1, 1;
                   70, 300, 3000, 0, 0;
                   100,0,   0,    0, 0];
%Total number of alternative levels for each epoch variable:
levels_epochvar = [4,3,3,2,2];