function [NPV_Epoch_Inflex] = MonteCarloNPV(T_con,Time_Charter_Contract,...
    CAPEX_Daily,OPEX_Daily,r_discount,Design_Space)
%This function calculates the NPV that can be achieved for an INFLEXIBLE
%vessel in each market in each epoch in an era. 

%Initializing:
num_periods = 5;
[num_designs,design_vars] = size(Design_Space);
[n,markets,T_life] = size(Time_Charter_Contract);
NPV_Epoch_Inflex = zeros(n,markets,num_designs,num_periods);

%Monte Carlo loop: 
for i = 1:n
    for d = 1:num_designs
        for m = 1:markets
            for t = 1:T_life
                %Finding NPV for each contract period, market and design. 
                if t < T_con+1
                    NPV_Epoch_Inflex(i,m,d,1) = ...
                        (350*Time_Charter_Contract(i,m,t) ...
                        - 365*(CAPEX_Daily(d,t) + OPEX_Daily(d,t)))/...
                        (1+r_discount) + NPV_Epoch_Inflex(i,m,d,1);
                elseif t >= T_con+1 && t < 2*T_con+1
                    NPV_Epoch_Inflex(i,m,d,2) = ...
                        (350*Time_Charter_Contract(i,m,t) ...
                        - 365*(CAPEX_Daily(d,t) + OPEX_Daily(d,t)))/...
                        (1+r_discount) + NPV_Epoch_Inflex(i,m,d,2);
                elseif t >= 2*T_con+1 && t < 3*T_con+1
                    NPV_Epoch_Inflex(i,m,d,3) = ...
                        (350*Time_Charter_Contract(i,m,t) ...
                        - 365*(CAPEX_Daily(d,t) + OPEX_Daily(d,t)))/...
                        (1+r_discount) + NPV_Epoch_Inflex(i,m,d,3);
                elseif t >= 3*T_con+1 && t < 4*T_con+1
                    NPV_Epoch_Inflex(i,m,d,4) = ...
                        (350*Time_Charter_Contract(i,m,t) ...
                        - 365*(CAPEX_Daily(d,t) + OPEX_Daily(d,t)))/...
                        (1+r_discount) + NPV_Epoch_Inflex(i,m,d,4);
                elseif t >= 4*T_con+1 && t < 5*T_con+1
                    NPV_Epoch_Inflex(i,m,d,5) = ...
                        (350*Time_Charter_Contract(i,m,t) ...
                        - 365*(CAPEX_Daily(d,t) + OPEX_Daily(d,t)))/...
                        (1+r_discount) + NPV_Epoch_Inflex(i,m,d,5);
                end
            end
        end
    end
end
end