function Time_Charter_Contract = MonteCarloTimeCharter...
    (Time_Charter_Rates,T_life,T_con,n,dT,MR_rate,StD,...
    OPEX_Daily,era,Era_Epoch_Progression,All_Contracts_Availability)
%This function simulates the time charter rates for the vessels (day rate), 
%based on a mean reverting process. 

%Initializing: 
markets = length(Time_Charter_Rates);
Time_Charter_Simulated = zeros(n,markets,T_life);
d_Time_Charter = zeros(n,markets,T_life);
Time_Charter_Mean = zeros(markets,T_life);
Time_Charter_Contract = zeros(n,markets,T_life);

%Monte Carlo loop: 
for i = 1:n
    %Generating TC rates for each market. 
    for m = 1:markets
        %Yearly income from time charter rates:
        Time_Charter_Simulated(i,m,1) = Time_Charter_Rates(m);
        %Mean time charter rate. 
        Time_Charter_Mean(m,1) = Time_Charter_Rates(m);
        %Simulating time charter rates according to a mean reverting
        %process: 
        for t = 2:dT:T_life
            Time_Charter_Mean(m,t) = Time_Charter_Mean(m,t-1);
            %Change in time charter is a mean reverting process: 
            d_Time_Charter(i,m,t-1) = MR_rate(m)*(Time_Charter_Mean(m,t-1) ...
                - Time_Charter_Simulated(i,m,t-1))*dT ...
                + StD(m)*normrnd(0,StD(m));
            %Adding the change in time charter to the previous rate. 
            Time_Charter_Simulated(i,m,t) = ...
                (d_Time_Charter(i,m,t-1) + ...
                Time_Charter_Simulated(i,m,t-1));
        end
        for t = 1:T_life
            %Specifies which period each year belongs to. 
            if (t < T_con+1)
                tt = 1;
            elseif (t >= T_con+1) && (t < 2*T_con+1)
                tt = 2;
            elseif (t >= 2*T_con+1) && (t < 3*T_con+1)
                tt = 3;
            elseif (t >= 3*T_con+1) && (t < 4*T_con+1)
                tt = 4;
            elseif (t >= 4*T_con+1) && (t < 5*T_con+1)
                tt = 5;
            end
            %Time charter is agreed for five years.
            if ((t == 1) || (t == T_con+1) || (t == 2*T_con+1) || ...
                    (t == 3*T_con+1) || (t == 4*T_con+1))
                %Accounting for the probability of winning a contract.
                %Also accounting for lay up when TC are below OPEX. 
                if ((rand() > (All_Contracts_Availability...
                        (Era_Epoch_Progression(tt,era(i)),m))/...
                        max(All_Contracts_Availability...
                        (Era_Epoch_Progression(tt,:),m)))) || ...
                        (Time_Charter_Simulated(i,m,t) ...
                        < min(OPEX_Daily(:)))
                    Time_Charter_Contract(i,m,t) = 0;
                else
                    Time_Charter_Contract(i,m,t) = ...
                        Time_Charter_Simulated(i,m,t);
                end
            else
                Time_Charter_Contract(i,m,t) = ...
                    Time_Charter_Contract(i,m,t-1);
            end
        end
    end
end
end