function [Total_Pareto_Set,Total_Pareto_Set_Eras,Pareto_Set_Eras,...
    Pareto_Set,Pareto_Trace] = Pareto...
    (Utility,CAPEX_Total,Total_Utility,Utility_Era,Total_Utility_Era)
%This function identifies the Pareto frontier for the tradespaces of each
%epoch. 

%Initializing: 
[num_epochs,num_designs] = size(Utility);
[num_eras,num_designs] = size(Utility_Era);

%For each epoch: 
for e = 1:num_epochs
    %Condition for while loop: 
    i = 0;
    %The first element in the Pareto array: 
    k = 1;
    while i == 0
        %Finding the maximum utility element. 
        [a,b] = max(Utility(e,:));
        %Adding point design to Pareto array. 
        Pareto_Set(e,k) = b;
        %Setting current max utility to -1 to avoid rechecking. 
        Utility(e,b) = -1;
        %Setting utility of all elements with a larger cost to -1.
        for j = 1:num_designs
            if CAPEX_Total(j) >= CAPEX_Total(b)
                Utility(e,j) = -1;
            end
        end
        %Exiting while loop when the lowest cost is reached or the max 
        %utility is 0. 
        if (CAPEX_Total(b) == min(CAPEX_Total(:))) || (max(Utility(e,:)) == 0)
            i = 1;
        end
        %For finding next element in Pareto array. 
        k = k+1;
    end
end
%Same procedure for multi-epoch (total utility): 
%Condition for while loop: 
i = 0;
%The first element in the Pareto array: 
l = 1;
while i == 0
    %Finding the maximum utility element. 
    [c,d] = max(Total_Utility(:));
    %Adding point design to Pareto array. 
    Total_Pareto_Set(l) = d;
    %Setting current max utility to -1 to avoid rechecking. 
    Total_Utility(d) = -1;
    %Setting utility of all elements with a larger cost to -1.
    for j = 1:num_designs
        if CAPEX_Total(j) >= CAPEX_Total(d)
            Total_Utility(j) = -1;
        end
    end
    %Exiting while loop when the lowest cost is reached. 
    if (CAPEX_Total(d) == min(CAPEX_Total(:))) || ...
            (max(Total_Utility(:)) == 0)
        i = 1;
    end
    %For finding next element in Pareto array. 
    l = l+1;
end

for q = 1:num_eras
%Same procedure for utility of each era: 
%Condition for while loop: 
i = 0;
%The first element in the Pareto array: 
m = 1;
while i == 0
    %Finding the maximum utility element. 
    [e,f] = max(Utility_Era(q,:));
    %Adding point design to Pareto array. 
    Pareto_Set_Eras(q,m) = f;
    %Setting current max utility to -1 to avoid rechecking. 
    Utility_Era(q,f) = -1;
    %Setting utility of all elements with a larger cost to -1.
    for j = 1:num_designs
        if CAPEX_Total(j) >= CAPEX_Total(f)
            Utility_Era(q,j) = -1;
        end
    end
    %Exiting while loop when the lowest cost is reached or the max 
    %utility is 0. 
        if (CAPEX_Total(f) == min(CAPEX_Total(:))) || ...
            (max(Utility_Era(q,:)) == 0)
        i = 1;
    end
    %For finding next element in Pareto array. 
    m = m+1;
end
end

%Same procedure for multi-era (total utility weighting all eras equally): 
%Condition for while loop: 
i = 0;
%The first element in the Pareto array: 
s = 1;
while i == 0
    %Finding the maximum utility element. 
    [g,h] = max(Total_Utility_Era(:));
    %Adding point design to Pareto array. 
    Total_Pareto_Set_Eras(s) = h;
    %Setting current max utility to -1 to avoid rechecking. 
    Total_Utility_Era(h) = -1;
    %Setting utility of all elements with a larger cost to -1.
    for j = 1:num_designs
        if CAPEX_Total(j) >= CAPEX_Total(h)
            Total_Utility_Era(j) = -1;
        end
    end
    %Exiting while loop when the lowest cost is reached or the max 
    %utility is 0. 
    if (CAPEX_Total(h) == min(CAPEX_Total(:))) || ...
            (max(Total_Utility_Era(:)) == 0)
        i = 1;
    end
    %For finding next element in Pareto array. 
    s = s+1;
end

%Finding the Pareto Trace (frequency of occurence of Pareto optimality): 
trace = unique(Pareto_Set);
Pareto_Trace_temp = [trace,histc(Pareto_Set(:),trace)];
Pareto_Trace = [Pareto_Trace_temp(:,1), Pareto_Trace_temp(:,2)/num_epochs];

end