%This script plots all the important results of the RSC process. Before
%running, you need to run "ResponsiveSystemsComparisonModel.m".

close all;

%% Tradespace Exploration:
%Plotting tradespaces for selected individual epochs. 
%Selecting epochs to plot:
epochs = [3]; %Test only one at the time, due to varying length of Pareto array. 
num_designs = length(CAPEX_Total);
[num_epochs,num_pareto] = size(Pareto_Set);
CAPEX_1 = [];
CAPEX_2 = [];
CAPEX_3 = [];
CAPEX_4 = [];
CAPEX_5 = [];
Utility_1 = [];
Utility_2 = [];
Utility_3 = [];
Utility_4 = [];
Utility_5 = [];
Total_Utility_1 = [];
Total_Utility_2 = [];
Total_Utility_3 = [];
Total_Utility_4 = [];
Total_Utility_5 = [];

%Grouping designs after total deck area.
for d = 1:num_designs
    if Total_Deck_Area(d) == 1000
        CAPEX_1 = [CAPEX_Total(d) CAPEX_1];
        Utility_1 = [Utility(:,d) Utility_1];
        Total_Utility_1 = [Total_Utility(d) Total_Utility_1];
    elseif Total_Deck_Area(d) == 1250
        CAPEX_2 = [CAPEX_Total(d) CAPEX_2];
        Utility_2 = [Utility(:,d) Utility_2];
        Total_Utility_2 = [Total_Utility(d) Total_Utility_2];
    elseif Total_Deck_Area(d) == 1500
        CAPEX_3 = [CAPEX_Total(d) CAPEX_3];
        Utility_3 = [Utility(:,d) Utility_3];
        Total_Utility_3 = [Total_Utility(d) Total_Utility_3];
    elseif Total_Deck_Area(d) == 1750
        CAPEX_4 = [CAPEX_Total(d) CAPEX_4];
        Utility_4 = [Utility(:,d) Utility_4];
        Total_Utility_4 = [Total_Utility(d) Total_Utility_4];
    elseif Total_Deck_Area(d) == 2000
        CAPEX_5 = [CAPEX_Total(d) CAPEX_5];
        Utility_5 = [Utility(:,d) Utility_5];
        Total_Utility_5 = [Total_Utility(d) Total_Utility_5];
    end   
end
%Plotting function: 
for i = 1:length(epochs);
    figure(i);
    scatter(CAPEX_1(:),Utility_1(epochs(i),:),27,'blue','LineWidth',1.5);
    hold on;
    scatter(CAPEX_2(:),Utility_2(epochs(i),:),27,'cyan','LineWidth',1.5);
    hold on;
    scatter(CAPEX_3(:),Utility_3(epochs(i),:),27,'green','LineWidth',1.5);
    hold on;
    scatter(CAPEX_4(:),Utility_4(epochs(i),:),27,'red','LineWidth',1.5);
    hold on;
    scatter(CAPEX_5(:),Utility_5(epochs(i),:),27,'black','LineWidth',1.5);
    hold on;
    for j = 1:num_pareto
        if Pareto_Set(epochs(i),j) > 0
        plot(CAPEX_Total(Pareto_Set(epochs(i),:)),Utility(epochs(i),Pareto_Set(epochs(i),:)),'color','r');%'*','MarkerEdgeColor','black','MarkerFaceColor','black');
        end
    end
    xlabel ('Total CAPEX [MNOK]');
    ylabel ('Utility for current epoch [-]');
    title ('Tradespace Exploration');
    
end
te = length(epochs);
%% Multi-Epoch Tradespace Exploration:
%Plotting the multi-epoch tradespace for the total weighted utility for all
%epochs weighted with equal probability of occurence. 
figure(te+1);
scatter(CAPEX_1(:),Total_Utility_1(:),27,'blue','LineWidth',1.5);
hold on;
scatter(CAPEX_2(:),Total_Utility_2(:),27,'cyan','LineWidth',1.5);
hold on;
scatter(CAPEX_3(:),Total_Utility_3(:),27,'green','LineWidth',1.5);
hold on;
scatter(CAPEX_4(:),Total_Utility_4(:),27,'red','LineWidth',1.5);
hold on;
scatter(CAPEX_5(:),Total_Utility_5(:),27,'black','LineWidth',1.5);
hold on;
if Total_Pareto_Set(j) > 0
    plot(CAPEX_Total(Total_Pareto_Set(:)),Total_Utility(Total_Pareto_Set(:)),'color','r');%'*','MarkerEdgeColor','black','MarkerFaceColor','black');
end

xlabel ('Total CAPEX [MNOK]');
ylabel ('Total Utility [-]');
title ('Multi-Epoch Tradespace Exploration');
me = te +1;

ee = me; %+ length(eras);
%% Lifecycle Analysis: 
%Plotting the cumulative probability distributions of NPV for inflexible 
%(red) and flexible (green) designs, and their mean NPVs. 
figure(ee+1);
infl = cdfplot(NPV_Vessel_Inflexible);
set(infl,'color','r','Marker','o');
hold on;
infl_mean = cdfplot(Mean_NPV_Inflexible);
set(infl_mean,'color','r');
hold on;
flex = cdfplot(NPV_Vessel_Flexible);
set(flex,'color','g','Marker','o');
hold on;
flex_mean = cdfplot(Mean_NPV_Flexible);
set(flex_mean,'color','g');
xlabel ('Net present value [MNOK]')
ylabel ('Cumulative probability')
title ('Comparing NPV for flexible and inflexible designs');
legend ('NPV Inflexible','ENPV Inflexible','NPV Flexible','ENPV Flexible','Location','SE');
figure(ee+2);
hist(NPV_Vessel_Inflexible,100)
xlabel ('Net present value [MNOK]')
ylabel ('Number of occurences')
title ('Histogram for NPV of inflexible design')
figure(ee+3);
hist(NPV_Vessel_Flexible,100)
xlabel ('Net present value [MNOK]')
ylabel ('Number of occurences')
title ('Histogram for NPV of flexible design')


