function Min_Req_Space = Requirements(Epoch_Space,Min_Req)
%This function defines the contractual requirements over time, as depending
%on the realization of epoch variables. Variables accounted for are: 
%Module size, Max water depth, Tie-in, Fibrerope technology

%Initializing: 
[num_epochs,epoch_var] = size(Epoch_Space);
[markets,design_vars] = size(Min_Req);
Min_Req_Space_1 = zeros(num_epochs,markets,epoch_var,design_vars);
Min_Req_Space = zeros(num_epochs,markets,design_vars);
for i = 1:num_epochs
    for m = 1:markets
        for v = 1:num_epochs
            for d = 1:design_vars
                Min_Req_Space_1(i,m,v,d)=Min_Req(m,d);
            end
        end
    end
end
for i = 1:num_epochs
    for m = 1:markets
        %Accounting for the impact single epoch variables have on the
        %requirements. 
        for v = 2:epoch_var
            %Epoch variable: Oil price:
            %No direct impact on minimum requirements. 
            %Epoch variable: Module size:
            if v == 2
                %No change if module size is 200 tonnes. 
                %Module size is 250 tonnes.
                if Epoch_Space(i,v) == 250
                    %IMR requirements:
                    if m == 1
                        %Will require module handling tower. 
                        Min_Req_Space_1(i,m,v,4) = 1;
                    %SURF requirements:
                    elseif m == 2
                        %Require 250 tonnes crane. 
                        Min_Req_Space_1(i,m,v,1) = Epoch_Space(i,v);
                        %Require 1250 m^2 free deck area. 
                        Min_Req_Space_1(i,m,v,2) = 1250;
                    end
                %Module size is 300 tonnes.
                elseif Epoch_Space(i,v) == 300
                    %IMR requirements:
                    if m == 1
                        %Will require module handling tower. 
                        Min_Req_Space_1(i,m,v,4) = 1;
                    %SURF requirements:
                    elseif m == 2
                        %Require 300 tonnes crane. 
                        Min_Req_Space_1(i,m,v,1) = Epoch_Space(i,v);
                        %Require 1500 m^2 free deck area.
                        Min_Req_Space_1(i,m,v,2) = 1500;
                    end
                end
            %Epoch variable: Maximum water depth:
            elseif v == 3
                %MAx water depth is 1000 m. No change from minimum. 
                %Max water depth is 2000 m:
                if Epoch_Space(i,v) == 2000
                    %IMR requirements:
                    if m == 1
                        %Will require 150 tonnes crane.
                        Min_Req_Space_1(i,m,v,1) = 150;
                        %Will require module handling tower. 
                        Min_Req_Space_1(i,m,v,4) = 1;
                        %Will require 2 ROVs. 
                        Min_Req_Space_1(i,m,v,11) = 2;
                    %SURF requirements:
                    elseif m == 2
                        %Will require 250 tonnes crane. 
                        Min_Req_Space_1(i,m,v,1) = 250;
                        %Will require 2 ROVs. 
                        Min_Req_Space_1(i,m,v,11) = 2;
                    %LWI requirements: 
                    elseif m == 3
                        %Will require 150 tonnes crane. 
                        Min_Req_Space_1(i,m,v,1) = 150;
                    end
                %Max water depth is 3000 m:
                elseif Epoch_Space(i,v) == 3000
                    %IMR requirements:
                    if m == 1
                        %Will require 200 tonnes crane.
                        Min_Req_Space_1(i,m,v,1) = 200;
                        %Will require module handling tower. 
                        Min_Req_Space_1(i,m,v,4) = 1;
                        %Will require 2 ROVs. 
                        Min_Req_Space_1(i,m,v,11) = 2;
                    %SURF requirements:
                    elseif m == 2
                        %Will require 300 tonnes crane. 
                        Min_Req_Space_1(i,m,v,1) = 300;
                        %Will require 2 ROVs. 
                        Min_Req_Space_1(i,m,v,11) = 2;
                    %LWI requirements: 
                    elseif m == 3
                        %Will require 200 tonnes crane. 
                        Min_Req_Space_1(i,m,v,1) = 200;
                    end                        
                end
            %Epoch variables: Tie-in need: 
            elseif v == 4
                if Epoch_Space(i,v) == 1
                    %SURF requirements.
                    if m == 2
                        %J-lay rig and carousel required. 
                        Min_Req_Space_1(i,m,v,6) = 1;
                        Min_Req_Space_1(i,m,v,7) = 1;
                        %Two ROVs required. 
                        Min_Req_Space_1(i,m,v,11) = 2;
                    end
                end
            end
        end
        %Accounting for epoch variable interactions on the requirements. 
        %Crane:  
        if (Epoch_Space(i,3) == 2000)
            %No fibrerope: 
            if (Epoch_Space(i,5) == 0)
                %Impact on SURF crane capacity: 
                Min_Req_Space_1(i,2,v,1) = Epoch_Space(i,2) + 50;
            %Fibrerope:
            elseif (Epoch_Space(i,5) == 1)
                Min_Req_Space_1(i,2,v,1) = Epoch_Space(i,2);
            end
        elseif (Epoch_Space(i,3) == 3000)
            %No fibrerope: 
            if (Epoch_Space(i,5) == 0)
                Min_Req_Space_1(i,2,v,1) = Epoch_Space(i,2) + 100;
            %Fibrerope: 
            elseif (Epoch_Space(i,5) == 1)
                Min_Req_Space_1(i,2,v,1) = Epoch_Space(i,2);
            end
        end  
    end
end
%Setting the minimum requirements in each epoch for each market:
for i = 1:num_epochs
    for m = 1:markets
        for d = 1:design_vars
            Min_Req_Space(i,m,d) = max(Min_Req_Space_1(i,m,:,d));
        end
    end
end
end