%This script runs through Step 2 - 6 of the Responsive Systems Comparison
%method. 

%% Step 2 and 3 of RSC: Design, attributes and epoch enumeration.
%Design space enumeration, generation of feasible designs: 
[Design_Space,Design_Space_infeasible,Total_Deck_Area] = ...
    Designs(Design_Variables,levels_desvar,Deck_Area,...
    Accommodation_Required,Min_Req);
%Cost model calculating CAPEX and OPEX:
[CAPEX_Total,CAPEX_Daily,OPEX_Daily] = ...
    Costs(Design_Variables,Design_Space,Total_Deck_Area,...
    T_life,T_payback,CAPEX_DV,r_discount);
%Epoch space enumeration: 
Epoch_Space = Epochs(levels_epochvar,Epoch_Variables);
%Defining contract requirements according to epochs:
Min_Req_Space = Requirements(Epoch_Space,Min_Req);
%Defining contract feasibility of designs in epochs: 
[All_Contracts,Contracts_Feasible,IMR_Contract,SURF_Contract,...
    LWI_Contract,DSV_Contract] = Contracts(Min_Req_Space,Design_Space);
%Defining contractual availability in epochs: 
[All_Contracts_Availability,IMR_Availability,SURF_Availability,...
    LWI_Availability,DSV_Availability] = AvailableContracts...
    (Epoch_Space,IMR_Contract,SURF_Contract,LWI_Contract,DSV_Contract);

%% Step 4 of RSC: Tradespace Exploration.
%Calculating utility for each design in each epoch:
[Utility] = Attributes(CAPEX_Daily,OPEX_Daily,Design_Space,...
    Total_Deck_Area,Contracts_Feasible,IMR_Availability,...
    SURF_Availability,LWI_Availability,DSV_Availability);

%% Step 5 of RSC: Multi-Epoch Evaluation.
%Calculating total average utility and ranks designs according to this.
[Total_Utility] = MultiEpoch(Utility,Design_Space);
%See also Pareto.m, MultiEpochEraAnalysis.m.

%% Step 6 of RSC: Era Construction.
%Constructing eras according to stakeholder expectations:
[Era_Description_Expectations,Era_Epoch_Progression] = ...
    EraConstruction(Epoch_Space);

%Performing multi-epoch analysis for the specified eras:
[Utility_Era,Total_Utility_Era] = MultiEpochEraAnalysis...
    (Utility,Era_Epoch_Progression);

%Finding Pareto fronts and Pareto trace: 
[Total_Pareto_Set,Total_Pareto_Set_Eras,Pareto_Set_Eras,...
    Pareto_Set,Pareto_Trace] = Pareto...
    (Utility,CAPEX_Total,Total_Utility,Utility_Era,Total_Utility_Era);
