function [Transition,Transition_Cost] = TransitionRules...
    (Design_Space,Total_Deck_Area,CAPEX_DV,Design_Variables,...
    T_life,T_con,cost_factor_remove,cost_factor_install)
%This function generates a NxN matrix defining whether a transition is
%allowed. It calculates the costs for making such transitions. 

%Initializing: 
[levels,design_vars] = size(Design_Variables);
num_periods = T_life/T_con;
[num_designs,design_vars] = size(Design_Space);
Transition = zeros(num_designs);
Transition_Cost = zeros(num_designs,num_designs,num_periods);
Transition_Cost_Temp = zeros(num_designs,num_designs,T_life);

%Defines which transitions from DESIGN i to j, are feasible. 
for i = 1:num_designs
    for j = 1:num_designs
        %Transition is possible if the total deck area remains the same. 
        if Total_Deck_Area(i) == Total_Deck_Area(j)
            Transition(i,j) = 1;
        end
    end
end
%Calculates the costs of making a transition from DESIGN i to DESIGN j: 
for i = 1:num_designs
    for j = 1:num_designs
        if Transition(i,j) == 1
            for k = 1:design_vars
                if Design_Space(i,k) ~= Design_Space(j,k)
                    %The cost of transitioning between designs.
                    for l = 1:levels
                        if (Design_Space(i,k) == Design_Variables(l,k))
                            Transition_Cost_Temp(i,j,1) ...
                                = cost_factor_remove*CAPEX_DV(l,k) ...
                                + Transition_Cost_Temp(i,j,1);
                        elseif (Design_Space(j,k) == Design_Variables(l,k))
                            Transition_Cost_Temp(i,j,1) ...
                                = cost_factor_install*CAPEX_DV(l,k) ...
                                + Transition_Cost_Temp(i,j,1);
                        end
                    end
                end
            end
        %Setting transition costs to infinity for illegal transitions. 
        else
            Transition_Cost_Temp(i,j,:) = inf;
        end
        for t = 2:T_life
            Transition_Cost_Temp(i,j,t) = Transition_Cost_Temp(i,j,t-1);
        end
        %Defines the transitions at the times transition is possible:
        Transition_Cost(i,j,1) = Transition_Cost_Temp(i,j,1);
        Transition_Cost(i,j,2) = Transition_Cost_Temp(i,j,T_con+1);
        Transition_Cost(i,j,3) = Transition_Cost_Temp(i,j,2*T_con+1);
        Transition_Cost(i,j,4) = Transition_Cost_Temp(i,j,3*T_con+1);
        Transition_Cost(i,j,5) = Transition_Cost_Temp(i,j,4*T_con+1);
    end
end
end